==> qore-1.12.0.tar.bz2: qore-1.12.0/docs/modules/RestClientDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "RestClientDataProvider", "namespace_rest_client_data_provider.html", [
      [ "RestClientCallDataProvider", "class_rest_client_data_provider_1_1_rest_client_call_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_call_data_provider" ],
      [ "RestClientCallRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_request_data_type" ],
      [ "RestClientCallResponseDataType", "class_rest_client_data_provider_1_1_rest_client_call_response_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_response_data_type" ],
      [ "RestClientCallWithMethodRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_with_method_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_with_method_request_data_type" ],
      [ "RestClientCallWithoutBodyRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_without_body_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_without_body_request_data_type" ],
      [ "RestClientDataProvider", "class_rest_client_data_provider_1_1_rest_client_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_data_provider" ],
      [ "RestClientDataProviderFactory", "class_rest_client_data_provider_1_1_rest_client_data_provider_factory.html", "class_rest_client_data_provider_1_1_rest_client_data_provider_factory" ],
      [ "RestClientDeleteDataProvider", "class_rest_client_data_provider_1_1_rest_client_delete_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_delete_data_provider" ],
      [ "RestClientGetDataProvider", "class_rest_client_data_provider_1_1_rest_client_get_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_get_data_provider" ],
      [ "RestClientHeadDataProvider", "class_rest_client_data_provider_1_1_rest_client_head_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_head_data_provider" ],
      [ "RestClientOptionsDataProvider", "class_rest_client_data_provider_1_1_rest_client_options_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_options_data_provider" ],
      [ "RestClientPatchDataProvider", "class_rest_client_data_provider_1_1_rest_client_patch_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_patch_data_provider" ],
      [ "RestClientPostDataProvider", "class_rest_client_data_provider_1_1_rest_client_post_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_post_data_provider" ],
      [ "RestClientPutDataProvider", "class_rest_client_data_provider_1_1_rest_client_put_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_put_data_provider" ]
    ] ]
];

==> qore-2.0.0.tar.bz2: qore-2.0.0/docs/modules/RestClientDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "RestClientDataProvider", "namespace_rest_client_data_provider.html", [
      [ "RestClientCallDataProvider", "class_rest_client_data_provider_1_1_rest_client_call_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_call_data_provider" ],
      [ "RestClientCallRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_request_data_type" ],
      [ "RestClientCallResponseDataType", "class_rest_client_data_provider_1_1_rest_client_call_response_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_response_data_type" ],
      [ "RestClientCallWithMethodRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_with_method_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_with_method_request_data_type" ],
      [ "RestClientCallWithoutBodyRequestDataType", "class_rest_client_data_provider_1_1_rest_client_call_without_body_request_data_type.html", "class_rest_client_data_provider_1_1_rest_client_call_without_body_request_data_type" ],
      [ "RestClientDataProvider", "class_rest_client_data_provider_1_1_rest_client_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_data_provider" ],
      [ "RestClientDataProviderBase", "class_rest_client_data_provider_1_1_rest_client_data_provider_base.html", "class_rest_client_data_provider_1_1_rest_client_data_provider_base" ],
      [ "RestClientDataProviderFactory", "class_rest_client_data_provider_1_1_rest_client_data_provider_factory.html", "class_rest_client_data_provider_1_1_rest_client_data_provider_factory" ],
      [ "RestClientDeleteDataProvider", "class_rest_client_data_provider_1_1_rest_client_delete_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_delete_data_provider" ],
      [ "RestClientGetDataProvider", "class_rest_client_data_provider_1_1_rest_client_get_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_get_data_provider" ],
      [ "RestClientHeadDataProvider", "class_rest_client_data_provider_1_1_rest_client_head_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_head_data_provider" ],
      [ "RestClientOptionsDataProvider", "class_rest_client_data_provider_1_1_rest_client_options_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_options_data_provider" ],
      [ "RestClientPatchDataProvider", "class_rest_client_data_provider_1_1_rest_client_patch_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_patch_data_provider" ],
      [ "RestClientPostDataProvider", "class_rest_client_data_provider_1_1_rest_client_post_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_post_data_provider" ],
      [ "RestClientPutDataProvider", "class_rest_client_data_provider_1_1_rest_client_put_data_provider.html", "class_rest_client_data_provider_1_1_rest_client_put_data_provider" ]
    ] ]
];
